Index: chrome/browser/plugin_process_host.cc |
diff --git a/chrome/browser/plugin_process_host.cc b/chrome/browser/plugin_process_host.cc |
index 7bbb5a75e9714f4fa448dd893db54100a347b84c..6ab2aaed713a1d59114eeeee3298fa85c2484ccf 100644 |
--- a/chrome/browser/plugin_process_host.cc |
+++ b/chrome/browser/plugin_process_host.cc |
@@ -1,4 +1,4 @@ |
-// Copyright (c) 2010 The Chromium Authors. All rights reserved. |
+// Copyright (c) 2011 The Chromium Authors. All rights reserved. |
// Use of this source code is governed by a BSD-style license that can be |
// found in the LICENSE file. |
@@ -59,14 +59,14 @@ static const char kDefaultPluginFinderURL[] = |
namespace { |
// Helper class that we pass to ResourceMessageFilter so that it can find the |
// right URLRequestContext for a request. |
class PluginURLRequestContextOverride |
: public ResourceMessageFilter::URLRequestContextOverride { |
public: |
PluginURLRequestContextOverride() { |
} |
- virtual URLRequestContext* GetRequestContext( |
+ virtual net::URLRequestContext* GetRequestContext( |
uint32 request_id, ResourceType::Type resource_type) { |
return CPBrowsingContextManager::GetInstance()->ToURLRequestContext( |
request_id); |
@@ -380,7 +380,7 @@ void PluginProcessHost::OpenChannelToPlugin(Client* client) { |
void PluginProcessHost::OnGetCookies(uint32 request_context, |
const GURL& url, |
std::string* cookies) { |
- URLRequestContext* context = CPBrowsingContextManager::GetInstance()-> |
+ net::URLRequestContext* context = CPBrowsingContextManager::GetInstance()-> |
ToURLRequestContext(request_context); |
// TODO(mpcomplete): remove fallback case when Gears support is prevalent. |
if (!context) |
@@ -59,14 +59,14 @@ static const char kDefaultPluginFinderURL[] = |
namespace { |
// Helper class that we pass to ResourceMessageFilter so that it can find the |
-// right URLRequestContext for a request. |
+// right net::URLRequestContext for a request. |
class PluginURLRequestContextOverride |
: public ResourceMessageFilter::URLRequestContextOverride { |